@@ -236,6 +236,10 @@ class Microservices(BaseClass, ABC):
             Metodo para el envio de una peticion a un topico, sin esperar
             una respuesta del mismo.
         """
+
+        if topic == "Errores_criticos":
+            return None
+
         id_trans = id_transaction if id_transaction is None else str(
             uuid.uuid4())
 
