@@ -1,5 +1,6 @@
 import base64
 import json
+import os
 import sys
 import _thread
 from kafka import KafkaConsumer, KafkaProducer
@@ -39,11 +40,13 @@ class KafkaBase:
         """
         topics = [self.__TOPIC, "validateConnection"]
 
+        CONSUMER_GROUP = os.environ.get('CONSUMER_GROUP', self.__TOPIC)
+
         # Conexion a kafka
         try:
             self.__CONSUMER = KafkaConsumer(
                 *topics,
-                group_id=self.__TOPIC,
+                group_id=CONSUMER_GROUP,
                 auto_offset_reset='earliest',
                 enable_auto_commit=True,
                 bootstrap_servers=self.__KAFKAHOSTS,
